@@ -8,10 +8,12 @@
 #'                       wise intercept values 
 #' @param p.value       (FALSE/TRUE) return a raster with the pixel 
 #'                       wise p.values
+#' @param z.value       (FALSE/TRUE) return a raster with the pixel 
+#'                       wise z.values
 #' @param confidence    (FALSE/TRUE) return a raster with the pixel 
 #'                       wise 95 pct confidence levels
 #' @param tau           (FALSE/TRUE) return a raster with the pixel wise 
-#'                       tau values
+#'                       tau correlation values
 #' @param ...           Additional arguments passed to the raster 
 #'                      overlay function
 #'
@@ -20,11 +22,12 @@
 #'   \item {raster layer 1} {slope for trend, always returned}
 #'   \item {raster layer 2} {intercept for trend if intercept TRUE}
 #'   \item {raster layer 3} {p value for trend fit if p.value TRUE}
-#'   \item {raster layer 4} {lower confidence level at 95 pct, if 
+#'   \item {raster layer 4} {z value for trend fit if z.value TRUE}
+#'   \item {raster layer 5} {lower confidence level at 95 pct, if 
 #'                           confidence TRUE}
-#'   \item {raster layer 5} {upper confidence level at 95 pct, if 
+#'   \item {raster layer 6} {upper confidence level at 95 pct, if 
 #'                           confidence TRUE}
-#'   \item {raster layer 6} {Kendall's tau two-sided test, reject null at 0, 
+#'   \item {raster layer 7} {Kendall's tau two-sided test, reject null at 0, 
 #'                           if tau TRUE}
 #' }
 #'
@@ -54,35 +57,47 @@
 #'  			    system.file("external/rlogo.grd", package="raster")) 
 #'  
 #'  # Calculate trend slope with p-value and confidence level(s)
-#'  logo.trend <- raster.kendall(r.logo, p.value=TRUE, confidence=TRUE)
-#'    names(logo.trend) <- c("slope","p.value","LCI","UCI")
-#'      plot(logo.trend)
+#'  # ("slope","intercept", "p.value","z.value", "LCI","UCI","tau")
+#'    k <- raster.kendall(r.logo, p.value=TRUE, z.value=TRUE, 
+#'                        intercept=TRUE, confidence=TRUE, 
+#'                        tau=TRUE)
+#'      plot(k)
 #' }
 #'
 #' @seealso \code{\link[EnvStats]{kendallTrendTest}} for model details
 #' @seealso \code{\link[raster]{overlay}} for available ... arguments
 #'
 #' @export
-raster.kendall <- function(x, intercept = FALSE, p.value = FALSE,   
+raster.kendall <- function(x, intercept = FALSE, p.value = FALSE, z.value = FALSE,   
                            confidence = FALSE, tau = FALSE, ...) {
-  if(!any(class(x) %in% c("RasterBrick","RasterStack"))) stop("x is not a raster stack or brick object")
+  if(!any(which(utils::installed.packages()[,1] %in% "EnvStats")))
+    stop("please install EnvStats package before running this function")
+  if(!any(class(x)[1] %in% c("RasterBrick","RasterStack"))) 
+    stop("x is not a raster stack or brick object")
+  if(confidence) {confidence = c(TRUE,TRUE)} else {confidence = c(FALSE,FALSE)}
+    n <- c("intercept", "p.value", "z.value", "LCI", "UCI", "tau")	
+	n <- n[which(c(intercept, p.value, z.value,confidence, tau))]	
     if( raster::nlayers(x) < 5) stop("Too few layers (n<5) to calculate a trend")
-  trend.slope <- function(y, p.value.pass = p.value, tau.pass = tau, confidence.pass = confidence,
+  trend.slope <- function(y, tau.pass = tau, p.value.pass = p.value,  
+                          confidence.pass = confidence[1], z.value.pass = z.value,
                           intercept.pass = intercept) {
-    fit <- EnvStats::kendallTrendTest(y ~ 1)
+    fit <- suppressWarnings( EnvStats::kendallTrendTest(y ~ 1) )
       fit.results <- fit$estimate[2]
         if(p.value.pass == TRUE) { fit.results <- c(fit.results, fit$p.value) } 
-  	      if(confidence.pass == TRUE) { 
-		    ci <- unlist(fit$interval["limits"])
-		      if( length(ci) == 2) { 
-		        fit.results <- c(fit.results, ci)
-              } else {
-                fit.results <- c(fit.results, c(NA,NA))
-              }			  
-		  }
+		  if(z.value.pass == TRUE) { fit.results <- c(fit.results, fit$statistic) } 
+  	        if(confidence.pass == TRUE) { 
+		      ci <- unlist(fit$interval["limits"])
+		        if( length(ci) == 2) { 
+		          fit.results <- c(fit.results, ci)
+                } else {
+                  fit.results <- c(fit.results, c(NA,NA))
+                }			  
+		    }
         if(intercept.pass == TRUE) { fit.results <- c(fit.results, fit$estimate[3]) }  
 		  if(tau.pass == TRUE) { fit.results <- c(fit.results, fit$estimate[1]) }  
     return( fit.results )
   }
-  return( raster::overlay(x, fun=trend.slope, ...) )
+  k <- raster::overlay(x, fun=trend.slope, ...)
+    names(k) <- c("slope", n)
+  return( k )
 }
